@@ -392,6 +392,11 @@ class SlipInfoText(SlipInformation):
             self.textctrl.WriteText(self.text)
             self._resize()
 
+class SlipService:
+    '''an object to change the map service'''
+    def __init__(self, service):
+        self.service = service
+
 
 class SlipObjectSelection:
     '''description of a object under the cursor during an event'''
@@ -620,6 +625,11 @@ class MPSlipMapFrame(wx.Frame):
                     state.info[obj.key] = obj
                 state.need_redraw = True
 
+            if isinstance(obj, SlipService):
+                # change map service
+                state.mt.set_service(obj.service)
+                state.need_redraw = True
+
             if isinstance(obj, SlipCenter):
                 # move center
                 (lat,lon) = obj.latlon
@@ -983,7 +993,7 @@ if __name__ == "__main__":
     parser.add_option("--thumbnail", default=None, help="show thumbnail")
     parser.add_option("--icon", default=None, help="show icon")
     parser.add_option("--flag", default=[], type='str', action='append', help="flag positions")
-    parser.add_option("--grid", default=None, help="add a UTM grid")
+    parser.add_option("--grid", default=False, action='store_true', help="add a UTM grid")
     parser.add_option("--elevation", action='store_true', default=False, help="show elevation information")
     parser.add_option("--verbose", action='store_true', default=False, help="show mount actions")
     (opts, args) = parser.parse_args()
